UINT FetchMail(LPVOID pParam);
//CString get_last_uid(CString &buf);
//BOOL check_uid_cache(CString uid, CString path);
